import { ValidationError } from 'class-validator';
import { eCheckResult } from '../../../../consts';
import { AllowPrimitives } from '../../../../types';
import { iRDetailedStatusOptical, RDetailedStatusOptical } from './detailed-status-optical.model';
import { iRDetailedStatusSummary, RDetailedStatusSummary } from './detailed-status-summary.model';
import { iRDetailedStatusRfid, RDetailedStatusRfid } from './detailed-status-rfid.model';
/**
* Get detailed status of a document processing
*/
export interface iRDetailedStatus {
    /**
    * Overall status
    * @type {eCheckResult}
    */
    overallStatus: eCheckResult;
    /**
    * Detailed status of optical checks
    * @type {iRDetailedStatusOptical}
    */
    optical: iRDetailedStatusOptical;
    /**
    * Detailed status of RFID checks
    * @type {iRDetailedStatusRfid}
    */
    rfId: iRDetailedStatusRfid;
    /**
    * Summary of all checks
    * @type {iRDetailedStatusOptical}
    */
    summary: iRDetailedStatusSummary;
}
/**
* Get detailed status of a document processing
*/
export declare class RDetailedStatus implements iRDetailedStatus {
    /**
    * Overall status
    * @type {eCheckResult}
    */
    overallStatus: eCheckResult;
    /**
    * Optical statuses
    * @type {RDetailedStatusOptical}
    */
    optical: RDetailedStatusOptical;
    /**
    * Detailed status of RFID checks
    * @type {RDetailedStatusRfid}
    */
    rfId: RDetailedStatusRfid;
    /**
    * Summary of all checks
    * @type {RDetailedStatusSummary}
    */
    summary: RDetailedStatusSummary;
    /**
    * Create a RDetailedStatus instance from plain object
    * @param {AllowPrimitives<iRDetailedStatus>} input
    * @returns {RDetailedStatus}
    */
    static fromPlain: (input: AllowPrimitives<iRDetailedStatus>) => RDetailedStatus;
    /**
    * Get validation errors
    * @param {RDetailedStatus} input
    * @returns {ValidationError[]}
    */
    static getValidationErrors: (input: RDetailedStatus) => ValidationError[];
    /**
    * Check if input is valid
    * @param {RDetailedStatus | RDetailedStatus[]} input - Array of RDetailedStatus instances or single instance
    * @returns {boolean}
    */
    static isValid: (input: RDetailedStatus | RDetailedStatus[]) => boolean;
}
